@@ -1,10 +1,10 @@
 ;;; supercite.el --- minor mode for citing mail and news replies
 
 ;; Author: 1993 Barry A. Warsaw, Century Computing, Inc. <bwarsaw@python.org>
-;; Maintainer:    supercite-help@python.org
+;; Maintainer:    The XEmacs Development Team <xemacs-beta@xemacs.org>
 ;; Created:       February 1993
 ;; Version:       3.1
-;; Last Modified: 1993/09/22 18:58:46
+;; Last Modified: Fri Aug  4 15:01:46 CEST 2000
 ;; Keywords: citation attribution mail news article reply followup
 
 ;; supercite.el revision: 3.55-x
@@ -24,7 +24,7 @@
 ;; General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with XEmacs; see the file COPYING.  If not, write to the 
+;; along with XEmacs; see the file COPYING.  If not, write to the
 ;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 ;; Boston, MA 02111-1307, USA.
 
@@ -38,7 +38,7 @@
 ;; sb 1997/May/07:  Add autoloads
 ;; sb 1997/Apr/02:  Added attribution function sc-header-author-email-writes
 ;; which gives attribution in the form -
-;; Steve Baur <steve@altair.xemacs.org> writes:
+;; Steve Baur <steve@xemacs.org> writes:
 
 ;; Modified by Bob Weiner <weiner@infodock.com>, 8/5/95, for use in InfoDock.
 ;;   Added sc-rewrite-address-function and sc-rewrite-region-function
@@ -278,7 +278,7 @@ nil       -- do not cite the region at all
 	     the number of lines in the region is greater than this
 	     value, a warning message will be printed and the region
 	     will not be cited.  Lines in region are counted with
-	     `count-lines'. 
+	     `count-lines'.
 
 The gathering of attribution information is not affected by the value
 of this variable.  The number of lines in the region is calculated
@@ -454,9 +454,13 @@ and the return value must be a string, which is used as the selected
 attribution.  Note that the variable `sc-preferred-attribution-list'
 must contain an element of the string \"sc-consult\" for this variable
 to be consulted during attribution selection."
-  :type '(repeat (list string (repeat (cons regexp
-					    (choice (repeat (repeat sexp))
-						    string)))))
+  :type '(repeat (group (string :tag "Infokey")
+			(repeat :format "\n%v%i\n"
+				(cons :format "\n%v"
+				      (regexp :tag "     Regexp")
+				      (choice :tag "Attribution"
+					      :format "%{%t%}: %[choice%] %v"
+					      sexp string)))))
   :group 'supercite-attr)
 
 (defcustom sc-attribs-preselect-hook nil
@@ -629,7 +633,7 @@ If this is nil, Supercite keymap is not installed.")
   (define-key sc-mode-map "\C-b" 'sc-submit-bug-report)
   (define-key sc-mode-map "?"    'sc-describe)
   )
-  
+
 (defvar sc-electric-mode-map ()
   "Keymap for `sc-electric-mode' electric references mode.")
 (if sc-electric-mode-map
@@ -789,9 +793,7 @@ the list should be unique."
 		 (thing   (cdr ml-elem)))
 	    (if (string-match regexp infoval)
 		;; we found a match, time to return
-		(setq rtnvalue (if (consp thing)
-				   (car thing)
-				 thing)
+		(setq rtnvalue thing
 		      mlist nil
 		      alist nil)
 	      ;; else we didn't find a match
@@ -1009,7 +1011,7 @@ of \"%\" and addresses of the style ``[stuff]name@[stuff]'' when
 called with DELIM \"@\".  If DELIM is nil or not provided, matches
 addresses of the style ``name''."
   ;; Handle X.400 addresses where G & S fields contain the sender name.
-  (if (string-match "/[GS]=\\([-a-zA-Z0-9_.]+\\)\\|\\([-+a-zA-Z0-9_.]+\\)" from)
+  (if (string-match (concat "/[GS]=\\([-a-zA-Z0-9_.]+\\)\\|\\([-+a-zA-Z0-9_.]+\\)" delim) from)
       (if (match-beginning 2)
 	  (substring from (match-beginning 2) (match-end 2))
 	(substring from (match-beginning 1) (match-end 1)))))
@@ -1178,7 +1180,7 @@ supplied, is used instead of the line point is on in the current buffer."
 This populates the `sc-attributions' with the list of possible attributions."
   (if (and (stringp from)
 	   (< 0 (length from)))
-      (let* ((sc-mumble "")	     
+      (let* ((sc-mumble "")
 	     (namestring (sc-attribs-extract-namestring from))
 	     (namelist   (sc-attribs-filter-namelist
 			  (sc-attribs-chop-namestring namestring)))
@@ -1190,7 +1192,7 @@ This populates the `sc-attributions' with the list of possible attributions."
 	     (emailname  (sc-attribs-emailname from))
 	     (n 1)
 	     author middlenames)
-    
+
 	;; put basic information
 	(setq
 	 ;; put middle names and build sc-author entry
@@ -1366,7 +1368,7 @@ to the auto-selected attribution string."
 	      (setq citation choice
 		    attribution (or (sc-guess-attribution citation)
 				    citation))
-	    
+
 	    (setq citation (sc-make-citation choice)
 		  attribution choice))
 	  ))
@@ -1568,7 +1570,7 @@ First runs `sc-pre-uncite-hook'."
 		   sc-default-uncite-frame)))
     (run-hooks 'sc-pre-uncite-hook)
     (regi-interpret frame start end)))
-      
+
 (defun sc-recite-region (start end)
   "Recite a region delineated by START and END.
 First runs `sc-pre-recite-hook'."
@@ -1700,7 +1702,7 @@ Treats these fields in a similar manner to `sc-header-on-said'."
 			" for more details)\n")
 		))))
 
-;; Added by Steve Baur <steve@altair.xemacs.org> Apr-02-1997.
+;; Added by Steve Baur <steve@xemacs.org> Apr-02-1997.
 (defun sc-header-author-email-writes ()
   "sc-author <email-addr> writes:"
   (let ((sc-mumble "")
@@ -1740,7 +1742,7 @@ error occurs."
 	(progn
 	  (eval ref)
 	  (let ((lines (count-lines (point-min) (point-max))))
-	    (or nomsg (message "Ref header %d [%d line%s]: %s" 
+	    (or nomsg (message "Ref header %d [%d line%s]: %s"
 			       sc-eref-style lines
 			       (if (= lines 1) "" "s")
 			       ref))))
@@ -2055,7 +2057,7 @@ before, and `sc-post-hook' is run after the guts of this function."
 	 (mark-active t)		; for FSFmacs
 	 (point (point-marker))
 	 (mark  (copy-marker (mark-marker))))
-  
+
     ;; make sure point comes before mark, not all functions are
     ;; interactive "r"
     (if (< mark point)
